@@ -2,10 +2,10 @@
 #
 # Encoding of Arabic: Dil Parkinson's Notation ###################################### 2006/02/03
 
-# $Id: Parkinson.pm 143 2006-11-15 01:16:57Z smrz $
-
 package Encode::Arabic::Parkinson;
 
+our $VERSION = '14.1';
+
 use 5.008;
 
 use strict;
@@ -13,13 +13,10 @@ use warnings;
 
 use Scalar::Util 'blessed';
 
-our $VERSION = do { q $Revision: 143 $ =~ /(\d+)/; sprintf "%4.2f", $1 / 100 };
-
-
 use Encode::Encoding;
 use base 'Encode::Encoding';
 
-__PACKAGE__->Define('Parkinson');
+__PACKAGE__->Define('Parkinson', 'Dil');
 
 
 our $enmode;
@@ -66,6 +63,8 @@ sub import {            # perform import as if Encode were used one level before
 
     require Encode;
 
+    push @Encode::ISA, 'Exporter' unless Encode->can('export_to_level');
+
     Encode->export_to_level(1, @_);
 }
 
@@ -75,7 +74,11 @@ sub encode ($$;$) {
 
     $_[1] = '' if $check;                   # needed by in-place edit
 
-    return encoder $text;
+    $text = encoder $text;
+
+    $text = Encode::encode "utf8", $text if Encode::is_utf8($text);
+
+    return $text;
 }
 
 
@@ -84,7 +87,11 @@ sub decode ($$;$) {
 
     $_[1] = '' if $check;                   # needed by in-place edit
 
-    return decoder $text;
+    $text = Encode::decode "utf8", $text unless Encode::is_utf8($text);
+
+    $text = decoder $text;
+
+    return $text;
 }
 
 
@@ -109,18 +116,17 @@ sub enmode ($$;$$) {
 
                 ( $kshd
                     ? ''
-                    : q [\x{640}] ) .
+                    : q [\x{0640}] ) .
                 q [\x{0623}\x{0624}\x{0625}] .
                 q [\x{060C}\x{061B}\x{061F}] .
                 q [\x{0621}\x{0622}\x{0626}-\x{063A}\x{0641}-\x{064A}] .
-              # q [\x{067E}\x{0686}\x{0698}\x{06A4}\x{06AF}] .
                 q [\x{0660}-\x{0669}] .
                 q [\x{0671}] .
                 q [\x{0651}] .
                 q [\x{064B}-\x{0650}\x{0670}] .
                 q [\x{0652}] .
                 ( $kshd
-                    ? q [\x{640}]
+                    ? q [\x{0640}]
                     : '' )
 
                 ,
@@ -128,12 +134,9 @@ sub enmode ($$;$$) {
                 ( $kshd
                     ? ''
                     : q [_] ) .
-                ( $xml
-                    ? q [LWE]
-                    : q [LWE] ) .
+                q [LWE] .
                 q [,;?] .
                 q [CMYAbQtVjHxdvrzspSDTZcgfqklmnhwey] .
-              # q [PJRVG] .
                 q [0-9] .
                 ( $mode == 0
                     ? q [O]
@@ -189,12 +192,9 @@ sub demode ($$;$$) {
                 ( $kshd
                     ? ''
                     : q [_] ) .
-                ( $xml
-                    ? q [LWE]
-                    : q [LWE] ) .
+                q [LWE] .
                 q [,;?] .
                 q [CMYAbQtVjHxdvrzspSDTZcgfqklmnhwey] .
-              # q [PJRVG] .
                 q [0-9] .
                 q [O] .
                 q [~] .
@@ -208,11 +208,10 @@ sub demode ($$;$$) {
 
                 ( $kshd
                     ? ''
-                    : q [\x{640}] ) .
+                    : q [\x{0640}] ) .
                 q [\x{0623}\x{0624}\x{0625}] .
                 q [\x{060C}\x{061B}\x{061F}] .
                 q [\x{0621}\x{0622}\x{0626}-\x{063A}\x{0641}-\x{064A}] .
-              # q [\x{067E}\x{0686}\x{0698}\x{06A4}\x{06AF}] .
                 q [\x{0660}-\x{0669}] .
                 ( $mode == 0
                     ? q [\x{0671}]
@@ -256,33 +255,18 @@ __END__
 Encode::Arabic::Parkinson - Dil Parkinson's transliteration of Arabic
 
 
-=head1 REVISION
-
-    $Revision: 143 $        $Date: 2006-11-15 02:16:57 +0100 (Wed, 15 Nov 2006) $
-
-
 =head1 SYNOPSIS
 
     use Encode::Arabic::Parkinson;          # imports just like 'use Encode' would, plus more
 
     while ($line = <>) {                    # Dil Parkinson's mapping into the Arabic script
 
-        print encode 'utf8', decode 'parkinson', $line;
+        print encode 'utf8', decode 'parkinson', $line;     # 'Parkinson' alias 'Dil'
     }
 
     # shell filter of data, e.g. in *n*x systems instead of viewing the Arabic script proper
 
-    % perl -MEncode::Arabic::Parkinson -pe 'encode "parkinson", decode "utf8", $_'
-
-    # employing the modes of conversion for filtering and trimming
-
-    Encode::Arabic::enmode 'parkinson', 'nosukuun', 'LWE xml';
-    Encode::Arabic::Parkinson->demode(undef, undef, 'strip _');
-
-    $decode = "AiqoraLo hRvaA Ol_n~a_S~a bi___OnotibaAhI.";
-    $encode = encode 'parkinson', decode 'parkinson', $decode;
-
-    # $encode eq "AiqraL hRvaA Aln~aS~a biAntibaAhI."
+    % perl -MEncode::Arabic::Parkinson -pe '$_ = encode "parkinson", decode "utf8", $_'
 
 
 =head1 DESCRIPTION
@@ -296,61 +280,19 @@ Arabic, using lower ASCII characters to encode the graphemes of the original scr
 Similar to that in L<Encode::Arabic::Buckwalter|Encode::Arabic::Buckwalter>.
 
 
-=head2 EXPORTS & MODES
-
-The module exports as if C<use Encode> also appeared in the package. The other C<import> options are
-just delegated to L<Encode|Encode> and imports performed properly.
-
-The B<conversion modes> of this module allow to override the setting of the C<:xml> option, in addition to
-filtering out diacritical marks and stripping off I<kashida>. The modes and aliases relate like this:
-
-    our %Encode::Arabic::Parkinson::modemap = (
-
-            'default'       => 0,   'undef'         => 0,
-
-            'fullvocalize'  => 0,   'full'          => 0,
-
-            'nowasla'       => 4,
-
-            'vocalize'      => 3,   'nosukuun'      => 3,
-
-            'novocalize'    => 2,   'novowels'      => 2,   'none'          => 2,
-
-            'noshadda'      => 1,   'noneplus'      => 1,
-        );
-
-
-=over
-
-=item enmode (I<$obj,> $mode, $xml, $kshd)
-
-=item demode (I<$obj,> $mode, $xml, $kshd)
-
-These methods can be invoked directly or through the respective functions of L<Encode::Arabic|Encode::Arabic>. The
-meaning of the extra parameters follows from the L<examples of usage|/SYNOPSIS>.
-
-=back
-
-
 =head1 SEE ALSO
 
 L<Encode::Arabic|Encode::Arabic>, L<Encode|Encode>, L<Encode::Encoding|Encode::Encoding>
 
-Xerox Arabic Home Page  L<http://www.arabic-morphology.com/>
-
 
 =head1 AUTHOR
 
-Otakar Smrz, L<http://ufal.mff.cuni.cz/~smrz/>
-
-    eval { 'E<lt>' . ( join '.', qw 'otakar smrz' ) . "\x40" . ( join '.', qw 'mff cuni cz' ) . 'E<gt>' }
-
-Perl is also designed to make the easy jobs not that easy ;)
+Otakar Smrz C<< <otakar-smrz users.sf.net> >>, L<http://otakar-smrz.users.sf.net/>
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 by Otakar Smrz
+Copyright (C) 2003-2012 Otakar Smrz
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
